@@ -109,7 +109,7 @@ class Client:
         )
         return _json_decode(response)
 
-    def create_asset(self, content: bytes) -> Dict:
+    def create_asset(self, content: bytes, **optional_args) -> Dict:
         """Creates an asset handle, calls the POST /assets endpoint.
 
         >>> from las.client import Client
@@ -118,13 +118,20 @@ class Client:
 
         :param content: Content to POST
         :type content: bytes
+        :param name: Name of the asset
+        :type name: str
+        :param description: Description of the asset
+        :type description: str
         :return: Asset response from REST API
         :rtype: dict
 
         :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
  :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
         """
-        body = {'content': b64encode(content).decode()}
+        body = {
+            'content': b64encode(content).decode(),
+            **optional_args,
+        }
         return self._make_request(requests.post, '/assets', body=body)
 
     def list_assets(self, *, max_results: Optional[int] = None, next_token: Optional[str] = None) -> Dict:
@@ -167,33 +174,42 @@ class Client:
         """
         return self._make_request(requests.get, f'/assets/{asset_id}')
 
-    def update_asset(self, asset_id: str, content: bytes) -> Dict:
+    def update_asset(self, asset_id: str, **optional_args) -> Dict:
         """Updates an asset, calls the PATCH /assets/assetId endpoint.
 
         >>> from las.client import Client
         >>> client = Client()
-        >>> client.update_asset('<asset id>', b'<bytes data>')
+        >>> client.update_asset('<asset id>', content=b'<bytes data>')
 
         :param asset_id: Id of the asset
         :type asset_id: str
         :param content: Content to PATCH
         :type content: bytes
+        :param name: Name of the asset
+        :type name: str
+        :param description: Description of the asset
+        :type description: str
         :return: Asset response from REST API
         :rtype: dict
 
         :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
  :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
         """
-        body = {'content': b64encode(content).decode()}
-        return self._make_request(requests.patch, f'/assets/{asset_id}', body=body)
+        content = optional_args.get('content')
+        if content:
+            optional_args['content'] = b64encode(content).decode()
 
-    def create_batch(self, description: str) -> Dict:
+        return self._make_request(requests.patch, f'/assets/{asset_id}', body=optional_args)
+
+    def create_batch(self, **optional_args) -> Dict:
         """Creates a batch, calls the POST /batches endpoint.
 
         >>> from las.client import Client
         >>> client = Client()
         >>> client.create_batch(description='<description>')
 
+        :param name: Name of the batch
+        :type name: str
         :param description: Description of the batch
         :type description: str
         :return: Batch response from REST API
@@ -202,7 +218,7 @@ class Client:
         :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
  :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
         """
-        return self._make_request(requests.post, '/batches', body={'description': description})
+        return self._make_request(requests.post, '/batches', body=optional_args)
 
     def create_document(
             self,
@@ -396,16 +412,41 @@ class Client:
         }
         return self._make_request(requests.post, '/predictions', body=dictstrip(body))
 
-    def create_secret(self, data: dict, *, description: Optional[str] = None) -> Dict:
+    def list_predictions(self, *, max_results: Optional[int] = None, next_token: Optional[str] = None) -> Dict:
+        """List predictions available, calls the GET /predictions endpoint.
+
+        >>> from las.client import Client
+        >>> client = Client()
+        >>> client.list_predictions()
+
+        :param max_results: Maximum number of results to be returned
+        :type max_results: int
+        :param next_token: A unique token for each page, use the returned token to retrieve the next page.
+        :type next_token: str
+        :return: Predictions response from REST API without the content of each prediction
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        params = {
+            'maxResults': max_results,
+            'nextToken': next_token,
+        }
+        return self._make_request(requests.get, '/predictions', params=params)
+
+    def create_secret(self, data: dict, **optional_args) -> Dict:
         """Creates an secret handle, calls the POST /secrets endpoint.
 
         >>> from las.client import Client
         >>> client = Client()
         >>> data = {'username': '<username>', 'password': '<password>'}
-        >>> client.create_secret(data, '<description>')
+        >>> client.create_secret(data, description='<description>')
 
         :param data: Dict containing the data you want to keep secret
         :type data: str
+        :param name: Name of the secret
+        :type name: str
         :param description: Description of the secret
         :type description: str
         :return: Secret response from REST API
@@ -416,9 +457,9 @@ class Client:
         """
         body = {
             'data': data,
-            'description': description,
+            **optional_args,
         }
-        return self._make_request(requests.post, '/secrets', body=dictstrip(body))
+        return self._make_request(requests.post, '/secrets', body=body)
 
     def list_secrets(self, *, max_results: Optional[int] = None, next_token: Optional[str] = None) -> Dict:
         """List secrets available, calls the GET /secrets endpoint.
@@ -443,18 +484,20 @@ class Client:
         }
         return self._make_request(requests.get, '/secrets', params=params)
 
-    def update_secret(self, secret_id: str, data: dict, *, description: Optional[str] = None) -> Dict:
+    def update_secret(self, secret_id: str, *, data: Optional[dict] = None, **optional_args) -> Dict:
         """Updates an secret, calls the PATCH /secrets/secretId endpoint.
 
         >>> from las.client import Client
         >>> client = Client()
         >>> data = {'username': '<username>', 'password': '<password>'}
-        >>> client.update_secret('<secret id>', data, '<description>')
+        >>> client.update_secret('<secret id>', data, description='<description>')
 
         :param secret_id: Id of the secret
         :type secret_id: str
         :param data: Dict containing the data you want to keep secret
         :type data: str
+        :param name: Name of the secret
+        :type name: Optional[str]
         :param description: Description of the secret
         :type description: Optional[str]
         :return: Secret response from REST API
@@ -463,21 +506,18 @@ class Client:
         :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
  :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
         """
-        body = {
-            'data': data,
-            'description': description,
-        }
-        return self._make_request(requests.patch, f'/secrets/{secret_id}', body=dictstrip(body))
+        body = dictstrip({'data': data})
+        body.update(**optional_args)
+        return self._make_request(requests.patch, f'/secrets/{secret_id}', body=body)
 
     def create_transition(
         self,
-        name,
         transition_type: str,
-        in_schema: dict,
-        out_schema: dict,
         *,
+        in_schema: Optional[dict] = None,
+        out_schema: Optional[dict] = None,
         params: Optional[dict] = None,
-        description: Optional[str] = None,
+        **optional_args,
     ) -> Dict:
         """Creates a transition handle, calls the POST /transitions endpoint.
 
@@ -492,11 +532,11 @@ class Client:
         >>>     'imageUrl': '<image_url>',
         >>>     'credentials': {'username': '<username>', 'password': '<password>'}
         >>> }
-        >>> client.create_transition('<name>', 'docker', in_schema, out_schema, docker_params)
+        >>> client.create_transition('docker', in_schema=in_schema, out_schema=out_schema, params=docker_params)
         >>> # A typical manual transitions
         >>> assets = {'jsRemoteComponent': 'las:asset:<hex-uuid>', '<other asset name>': 'las:asset:<hex-uuid>'}
         >>> manual_params = {'assets': assets}
-        >>> client.create_transition('<name>', 'manual', in_schema, out_schema, manual_params)
+        >>> client.create_transition('manual', in_schema=in_schema, out_schema=out_schema, params=manual_params)
 
         :param in_schema: Json-schema that defines the input to the transition
         :type in_schema: dict
@@ -516,15 +556,14 @@ class Client:
         :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
  :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
         """
-        body = {
-            'name': name,
-            'description': description,
+        body = dictstrip({
             'inputJsonSchema': in_schema,
             'outputJsonSchema': out_schema,
             'transitionType': transition_type,
             'params': params,
-        }
-        return self._make_request(requests.post, '/transitions', body=dictstrip(body))
+        })
+        body.update(**optional_args)
+        return self._make_request(requests.post, '/transitions', body=body)
 
     def list_transitions(
         self,
@@ -557,16 +596,15 @@ class Client:
             'maxResults': max_results,
             'nextToken': next_token,
         }
-        return self._make_request(requests.get, url, params=params)
+        return self._make_request(requests.get, url, params=dictstrip(params))
 
     def update_transition(
         self,
         transition_id: str,
         *,
-        name: Optional[str],
-        in_schema: Optional[dict],
-        out_schema: Optional[dict],
-        description: Optional[str] = None,
+        in_schema: Optional[dict] = None,
+        out_schema: Optional[dict] = None,
+        **optional_args,
     ) -> Dict:
         """Creates a transition handle, calls the PATCH /transitions/{transitionId} endpoint.
 
@@ -592,13 +630,12 @@ class Client:
         :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
  :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
         """
-        body = {
-            'name': name,
-            'description': description,
+        body = dictstrip({
             'inputJsonSchema': in_schema,
             'outputJsonSchema': out_schema,
-        }
-        return self._make_request(requests.patch, f'/transitions/{transition_id}', body=dictstrip(body))
+        })
+        body.update(**optional_args)
+        return self._make_request(requests.patch, f'/transitions/{transition_id}', body=body)
 
     def execute_transition(self, transition_id: str) -> Dict:
         """Start executing a manual transition, calls the POST /transitions/{transitionId}/executions endpoint.
@@ -626,6 +663,8 @@ class Client:
         execution_id: Optional[Queryparam] = None,
         max_results: Optional[int] = None,
         next_token: Optional[str] = None,
+        sort_by: Optional[str] = None,
+        order: Optional[str] = None,
     ) -> Dict:
         """List executions in a transition, calls the GET /transitions/{transitionId}/executions endpoint.
 
@@ -637,6 +676,10 @@ class Client:
         :type transition_id: str
         :param status: Statuses of the executions
         :type status: Queryparam
+        :param order: Order of the executions, either 'ascending' or 'descending'
+        :type order: Optional str
+        :param sort_by: the sorting variable of the executions, either 'endTime', or 'startTime'
+        :type sort_by: Optional str
         :param execution_id: Ids of the executions
         :type execution_id: Queryparam
         :param max_results: Maximum number of results to be returned
@@ -655,8 +698,10 @@ class Client:
             'executionId': execution_id,
             'maxResults': max_results,
             'nextToken': next_token,
+            'order': order,
+            'sortBy': sort_by,
         }
-        return self._make_request(requests.get, url, params=params)
+        return self._make_request(requests.get, url, params=dictstrip(params))
 
     def update_transition_execution(
         self,
@@ -775,14 +820,7 @@ class Client:
         """
         return self._make_request(requests.delete, f'/users/{user_id}')
 
-    def create_workflow(
-        self,
-        specification: dict,
-        name: str,
-        *,
-        description: Optional[str] = None,
-        error_config: Optional[dict] = None,
-    ) -> Dict:
+    def create_workflow(self, specification: dict, *, error_config: Optional[dict] = None, **optional_args) -> Dict:
         """Creates a new workflow, calls the POST /workflows endpoint.
 
         >>> from las.client import Client
@@ -790,7 +828,7 @@ class Client:
         >>> client = Client()
         >>> specification = {'language': 'ASL', 'version': '1.0.0', 'definition': {...}}
         >>> error_config = {'email': '<error-recipient>'}
-        >>> client.create_workflow(specification, '<name>', '<description>', error_config)
+        >>> client.create_workflow(specification, error_config=error_config)
 
         :param specification: Specification of the workflow,
             currently supporting ASL: https://states-language.net/spec.html
@@ -807,13 +845,13 @@ class Client:
         :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
  :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
         """
-        body = {
+        body = dictstrip({
             'specification': specification,
-            'name': name,
-            'description': description,
             'errorConfig': error_config,
-        }
-        return self._make_request(requests.post, '/workflows', body=dictstrip(body))
+        })
+        body.update(**optional_args)
+
+        return self._make_request(requests.post, '/workflows', body=body)
 
     def list_workflows(self, *, max_results: Optional[int] = None, next_token: Optional[str] = None) -> Dict:
         """List workflows, calls the GET /workflows endpoint.
@@ -838,7 +876,7 @@ class Client:
         }
         return self._make_request(requests.get, '/workflows', params=params)
 
-    def update_workflow(self, workflow_id: str, *, name: Optional[str], description: Optional[str] = None) -> Dict:
+    def update_workflow(self, workflow_id: str, **optional_args) -> Dict:
         """Creates a workflow handle, calls the PATCH /workflows/{workflowId} endpoint.
 
         >>> import json
@@ -859,11 +897,7 @@ class Client:
         :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
  :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
         """
-        body = {
-            'name': name,
-            'description': description,
-        }
-        return self._make_request(requests.patch, f'/workflows/{workflow_id}', body=dictstrip(body))
+        return self._make_request(requests.patch, f'/workflows/{workflow_id}', body=optional_args)
 
     def delete_workflow(self, workflow_id: str) -> Dict:
         """Delete the workflow with the provided workflow_id, calls the DELETE /workflows/{workflowId} endpoint.
@@ -948,13 +982,13 @@ class Client:
         }
         return self._make_request(requests.get, url, params=params)
 
-    def stop_workflow_execution(self, workflow_id: str, execution_id: str) -> Dict:
-        """Stops the execution with the provided execution_id from workflow_id,
+    def delete_workflow_execution(self, workflow_id: str, execution_id: str) -> Dict:
+        """Deletes the execution with the provided execution_id from workflow_id,
         calls the DELETE /workflows/{workflowId}/executions/{executionId} endpoint.
 
         >>> from las.client import Client
         >>> client = Client()
-        >>> client.stop_workflow_execution('<workflow_id>', '<execution_id>')
+        >>> client.delete_workflow_execution('<workflow_id>', '<execution_id>')
 
         :param workflow_id: Id of the workflow
         :type workflow_id: str
